diff --git a/web/pgadmin/browser/server_groups/__init__.py b/web/pgadmin/browser/server_groups/__init__.py
index 8a83990..6044040 100644
--- a/web/pgadmin/browser/server_groups/__init__.py
+++ b/web/pgadmin/browser/server_groups/__init__.py
@@ -107,6 +107,16 @@ class ServerGroupView(NodeView):
     def delete(self, gid):
         """Delete a server group node in the settings database"""
 
+        # if server group id is 1 we won't delete it.
+        if gid == 1:
+            return make_json_response(
+                    status=417,
+                    success=0,
+                    errormsg=gettext(
+                        'The specified server group cannot be deleted.'
+                        )
+                    )
+
         # There can be only one record at most
         servergroup = ServerGroup.query.filter_by(
                 user_id=current_user.id,
diff --git a/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js b/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js
index e0f5171..55aec2f 100644
--- a/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js
+++ b/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js
@@ -19,11 +19,6 @@ function($, _, pgAdmin, Backbone) {
           applies: ['object', 'context'], callback: 'show_obj_properties',
           category: 'create', priority: 1, label: '{{ _('Server Group...') }}',
           data: {'action': 'create'}, icon: 'wcTabIcon icon-server-group'
-        }, {
-          name: 'drop_server_group', node: 'server-group', module: this,
-          applies: ['object', 'context'], callback: 'delete_obj',
-          priority: 2, label: '{{ _('Drop Server Group...') }}',
-          icon: 'fa fa-trash'
         }]);
       },
       model: pgAdmin.Browser.Node.Model.extend({
@@ -50,6 +45,12 @@ function($, _, pgAdmin, Backbone) {
           return null;
         }
       }),
+      canDrop: function(itemData, item, data) {
+        if(itemData._id == 1) {
+          return false;
+        }
+        return true;
+      },
       canDelete: function(i) {
         var s = pgAdmin.Browser.tree.siblings(i, true);
 
diff --git a/web/pgadmin/browser/templates/browser/js/node.js b/web/pgadmin/browser/templates/browser/js/node.js
index 68a760c..86e493c 100644
--- a/web/pgadmin/browser/templates/browser/js/node.js
+++ b/web/pgadmin/browser/templates/browser/js/node.js
@@ -470,7 +470,6 @@ function($, _, S, pgAdmin, Menu, Backbone, Alertify, pgBrowser, Backform) {
       delete_obj: function(args, item) {
           var input = args || {'url':'drop'};
           obj = this,
-          obj.canDrop = true
           t = pgBrowser.tree,
           i = input.item || item || t.selected(),
           d = i && i.length == 1 ? t.itemData(i) : undefined;
@@ -538,7 +537,7 @@ function($, _, S, pgAdmin, Menu, Backbone, Alertify, pgBrowser, Backform) {
               error: function(jqx) {
                 var msg = jqx.responseText;
                 /* Error from the server */
-                if (jqx.status == 410 || jqx.status == 500) {
+                if (jqx.status == 417 || jqx.status == 410 || jqx.status == 500) {
                   try {
                     var data = $.parseJSON(jqx.responseText);
                     msg = data.errormsg;
